# Welcome to probatus documentation!

<img src="img/logo_large.png" width=190 align="right">

**Probatus** is a Python library that allows to analyse binary classification models as well as the data used to develop them.
The main features assess the metric stability and analyse differences between two data samples e.g. shift between train and test splits.

## Installation

In order to install Probatus you need to use Python 3.6 or higher.

Install `probatus` via pip with:

```bash
pip install probatus
```

Alternatively you can fork/clone and run:

```bash
git clone https://gitlab.com/ing_rpaa/probatus.git
cd probatus
pip install .
```

For packages required for development, please refer to [requirements.txt](https://github.com/ing-bank/probatus/blob/main/requirements.txt).

## Licence

Probatus is created under MIT License, see more in [LICENCE file](https://github.com/ing-bank/probatus/blob/main/LICENCE).


